Class: Hyperion::AsyncPg::Patches
- Inherits:
-
Module
- Object
- Module
- Hyperion::AsyncPg::Patches
- Defined in:
- lib/hyperion/async_pg.rb
Overview
Module-builder. Receiving a list of methods, returns an anonymous Module that defines each one as an async-aware shim. Prepending it onto PG::Connection makes the shim run before the C method.
Instance Method Summary collapse
-
#initialize(methods) ⇒ Patches
constructor
A new instance of Patches.
Constructor Details
#initialize(methods) ⇒ Patches
Returns a new instance of Patches.
125 126 127 128 129 |
# File 'lib/hyperion/async_pg.rb', line 125 def initialize(methods) super() @methods = methods define_methods end |